import { CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { input, model, output, signal, Input, ViewChild, Component, NgModule } from '@angular/core';
import * as i5 from '@angular/forms';
import { UntypedFormControl, ReactiveFormsModule, FormsModule } from '@angular/forms';
import * as i1 from '@angular/material/autocomplete';
import { MatAutocompleteModule } from '@angular/material/autocomplete';
import * as i2 from '@angular/material/chips';
import { MatChipsModule } from '@angular/material/chips';
import * as i4 from '@angular/material/form-field';
import { MatFormFieldModule } from '@angular/material/form-field';
import * as i3 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';
import { ENTER } from '@angular/cdk/keycodes';
import { withDestroy, ArrayUtils, ObjectUtils } from '@tapsellorg/angular-material-library/src/lib/common';
import { takeUntil } from 'rxjs/operators';

class PghAutoCompleteComponent extends withDestroy() {
    constructor() {
        super();
        this.SEPARATOR_KEYS_CODES = [ENTER];
        this.label = input();
        this.placeholder = input('');
        this.maxCount = input();
        this.onlyDistinctValues = input(true);
        this.allowCustomValues = input(false);
        this.allowChipInputAddOnBlur = input(false);
        this.allValues = input([]);
        this.selectedValues = model([]);
        this.selectedValuesChange = output();
        this.selectionChange = output();
        this.selectedValuesControl = input();
        this.inputCtrl = input(new UntypedFormControl());
        this.filteredValues = signal([]);
        this.hasAutoComplete = false;
        this.valueProperty = input();
        this.nameProperty = input();
        this.valueGetter = (x) => this.valueProperty() ? x[this.valueProperty()] : x;
        this.nameGetter = (x) => this.nameProperty() ? x[this.nameProperty()] : x;
    }
    emit(changedEvent) {
        this.selectedValuesChange.emit(this.selectedValues());
        this.selectionChange.emit({ ...changedEvent, selectedValues: this.selectedValues() });
        this.selectedValuesControl()?.setValue?.(this.selectedValues());
    }
    ngOnInit() {
        this.inputCtrl().valueChanges.subscribe((val) => {
            this._filter(val);
        });
    }
    ngOnChanges(changes) {
        if (changes.allValues) {
            this.hasAutoComplete = this.allValues()?.length > 0;
            this._filter();
            if (this.selectedValues().some(o => !this.findEligibleValue(o))) {
                setTimeout(() => {
                    const previousSelectedValues = this.selectedValues().slice();
                    this.selectedValues.set([]);
                    this.emit({ changedItems: previousSelectedValues, type: 'remove' });
                });
            }
        }
        if (changes.selectedValuesControl && this.selectedValuesControl()) {
            this.addAlreadyExistedValues(this.selectedValuesControl().value);
            this.selectedValuesControl().valueChanges.subscribe((data) => {
                if (ArrayUtils.arraysAreSame(data, this.selectedValues()))
                    return;
                this.addAlreadyExistedValues(data);
            });
        }
    }
    ngAfterViewInit() {
        this.handleClosePanel();
    }
    handleClosePanel() {
        if (!this.matAutocompleteTrigger)
            return;
        this.matAutocompleteTrigger.panelClosingActions
            .pipe(takeUntil(this._destroyed$))
            .subscribe(data => {
            if (data?.isUserInput) {
                setTimeout(() => {
                    this.matAutocompleteTrigger.openPanel();
                });
            }
        });
    }
    addAlreadyExistedValues(values) {
        if (!values?.length)
            return;
        this.selectedValues.set(values);
    }
    add(event) {
        const { input, value } = event;
        if (!(value || '').trim())
            return;
        this.pushToSelectedValues(value.trim());
        if (input) {
            input.value = '';
        }
        this.inputCtrl().setValue(null);
    }
    remove(val) {
        if (!this.selectedValues().includes(val))
            return;
        this.selectedValues.set(this.selectedValues().filter(o => this.valueGetter(o) !== this.valueGetter(val)));
        this.emit({ changedItems: [val], type: 'remove' });
        this._filter();
    }
    findEligibleValue(value) {
        if (!value)
            return;
        if (this.allowCustomValues()) {
            if (this.onlyDistinctValues() && this.selectedValues().includes(value)) {
                return;
            }
            return value;
        }
        const possibleValues = this.allValues();
        return possibleValues.find(o => {
            if (typeof value === 'string') {
                return this.nameGetter(o) === value;
            }
            const objValue = this.valueGetter(o);
            const selectedVale = this.valueGetter(value);
            return (objValue === selectedVale ||
                ObjectUtils.isEqualObject(objValue, selectedVale));
        });
    }
    pushToSelectedValues(name) {
        if (this.selectedValues().length === this.maxCount())
            return;
        const value = this.findEligibleValue(name);
        if (!value)
            return;
        this.selectedValues().push(value);
        this._filter();
        this.emit({ changedItems: [value], type: 'add' });
    }
    onSelectOption(event) {
        this.pushToSelectedValues(event.option.value);
        if (this.inputElm) {
            this.inputElm.nativeElement.value = '';
        }
        this.inputCtrl().setValue(null);
    }
    _filter(value) {
        const allValues = this.calculatePossibleValues();
        this.filteredValues.set(value ? allValues.filter((val) => this.nameGetter(val).includes(value)) : allValues);
    }
    calculatePossibleValues() {
        return this.onlyDistinctValues()
            ? this.allValues().filter(val => !this.selectedValues().find(x => this.valueGetter(x) === this.valueGetter(val)))
            : this.allValues().slice();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: PghAutoCompleteComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.13", type: PghAutoCompleteComponent, isStandalone: false, selector: "pgh-auto-complete", inputs: { label: { classPropertyName: "label", publicName: "label", isSignal: true, isRequired: false, transformFunction: null }, placeholder: { classPropertyName: "placeholder", publicName: "placeholder", isSignal: true, isRequired: false, transformFunction: null }, maxCount: { classPropertyName: "maxCount", publicName: "maxCount", isSignal: true, isRequired: false, transformFunction: null }, onlyDistinctValues: { classPropertyName: "onlyDistinctValues", publicName: "onlyDistinctValues", isSignal: true, isRequired: false, transformFunction: null }, allowCustomValues: { classPropertyName: "allowCustomValues", publicName: "allowCustomValues", isSignal: true, isRequired: false, transformFunction: null }, allowChipInputAddOnBlur: { classPropertyName: "allowChipInputAddOnBlur", publicName: "allowChipInputAddOnBlur", isSignal: true, isRequired: false, transformFunction: null }, allValues: { classPropertyName: "allValues", publicName: "allValues", isSignal: true, isRequired: false, transformFunction: null }, selectedValues: { classPropertyName: "selectedValues", publicName: "selectedValues", isSignal: true, isRequired: false, transformFunction: null }, selectedValuesControl: { classPropertyName: "selectedValuesControl", publicName: "selectedValuesControl", isSignal: true, isRequired: false, transformFunction: null }, inputCtrl: { classPropertyName: "inputCtrl", publicName: "inputCtrl", isSignal: true, isRequired: false, transformFunction: null }, valueProperty: { classPropertyName: "valueProperty", publicName: "valueProperty", isSignal: true, isRequired: false, transformFunction: null }, nameProperty: { classPropertyName: "nameProperty", publicName: "nameProperty", isSignal: true, isRequired: false, transformFunction: null }, valueGetter: { classPropertyName: "valueGetter", publicName: "valueGetter", isSignal: false, isRequired: false, transformFunction: null }, nameGetter: { classPropertyName: "nameGetter", publicName: "nameGetter", isSignal: false, isRequired: false, transformFunction: null } }, outputs: { selectedValues: "selectedValuesChange", selectedValuesChange: "selectedValuesChange", selectionChange: "selectionChange" }, viewQueries: [{ propertyName: "inputElm", first: true, predicate: ["inputElm"], descendants: true }, { propertyName: "matAutocompleteTrigger", first: true, predicate: ["matAutocompleteTrigger"], descendants: true }], usesInheritance: true, usesOnChanges: true, ngImport: i0, template: "<mat-form-field class=\"w-100\">\n  <mat-label>{{ label() }}</mat-label>\n  <mat-chip-grid #chipList>\n    <!-- TODO: v17 removed from this element [selectable]=\"false\" -->\n    @for (item of selectedValues(); track item) {\n    <mat-chip-row color=\"primary\" [removable]=\"true\" (removed)=\"remove(item)\">\n      <mat-icon class=\"ms-0 me-2\" matChipRemove svgIcon=\"clear\"></mat-icon>\n      <span class=\"pgh-chips-text\">{{ nameGetter(item) }}</span>\n    </mat-chip-row>\n    }\n    <input\n      [placeholder]=\"placeholder()\"\n      #inputElm\n      #matAutocompleteTrigger=\"matAutocompleteTrigger\"\n      [formControl]=\"inputCtrl()\"\n      [matAutocomplete]=\"auto\"\n      [matChipInputFor]=\"chipList\"\n      [matChipInputSeparatorKeyCodes]=\"SEPARATOR_KEYS_CODES\"\n      [matChipInputAddOnBlur]=\"allowChipInputAddOnBlur()\"\n      (matChipInputTokenEnd)=\"add($event)\"\n    />\n  </mat-chip-grid>\n  <mat-autocomplete #auto=\"matAutocomplete\" (optionSelected)=\"onSelectOption($event)\">\n    @for (item of filteredValues(); track item) {\n    <mat-option [value]=\"item\">\n      <span>{{ nameGetter(item) }}</span>\n    </mat-option>\n    }\n  </mat-autocomplete>\n</mat-form-field>\n", styles: [".pgh-chips-text{margin-inline-end:.375rem}\n"], dependencies: [{ kind: "component", type: i1.MatAutocomplete, selector: "mat-autocomplete", inputs: ["aria-label", "aria-labelledby", "displayWith", "autoActiveFirstOption", "autoSelectActiveOption", "requireSelection", "panelWidth", "disableRipple", "class", "hideSingleSelectionIndicator"], outputs: ["optionSelected", "opened", "closed", "optionActivated"], exportAs: ["matAutocomplete"] }, { kind: "component", type: i1.MatOption, selector: "mat-option", inputs: ["value", "id", "disabled"], outputs: ["onSelectionChange"], exportAs: ["matOption"] }, { kind: "directive", type: i1.MatAutocompleteTrigger, selector: "input[matAutocomplete], textarea[matAutocomplete]", inputs: ["matAutocomplete", "matAutocompletePosition", "matAutocompleteConnectedTo", "autocomplete", "matAutocompleteDisabled"], exportAs: ["matAutocompleteTrigger"] }, { kind: "component", type: i2.MatChipGrid, selector: "mat-chip-grid", inputs: ["disabled", "placeholder", "required", "value", "errorStateMatcher"], outputs: ["change", "valueChange"] }, { kind: "directive", type: i2.MatChipInput, selector: "input[matChipInputFor]", inputs: ["matChipInputFor", "matChipInputAddOnBlur", "matChipInputSeparatorKeyCodes", "placeholder", "id", "disabled"], outputs: ["matChipInputTokenEnd"], exportAs: ["matChipInput", "matChipInputFor"] }, { kind: "directive", type: i2.MatChipRemove, selector: "[matChipRemove]" }, { kind: "component", type: i2.MatChipRow, selector: "mat-chip-row, [mat-chip-row], mat-basic-chip-row, [mat-basic-chip-row]", inputs: ["editable"], outputs: ["edited"] }, { kind: "component", type: i3.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "component", type: i4.MatFormField, selector: "mat-form-field", inputs: ["hideRequiredMarker", "color", "floatLabel", "appearance", "subscriptSizing", "hintLabel"], exportAs: ["matFormField"] }, { kind: "directive", type: i4.MatLabel, selector: "mat-label" }, { kind: "directive", type: i5.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i5.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i5.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: PghAutoCompleteComponent, decorators: [{
            type: Component,
            args: [{ selector: 'pgh-auto-complete', standalone: false, template: "<mat-form-field class=\"w-100\">\n  <mat-label>{{ label() }}</mat-label>\n  <mat-chip-grid #chipList>\n    <!-- TODO: v17 removed from this element [selectable]=\"false\" -->\n    @for (item of selectedValues(); track item) {\n    <mat-chip-row color=\"primary\" [removable]=\"true\" (removed)=\"remove(item)\">\n      <mat-icon class=\"ms-0 me-2\" matChipRemove svgIcon=\"clear\"></mat-icon>\n      <span class=\"pgh-chips-text\">{{ nameGetter(item) }}</span>\n    </mat-chip-row>\n    }\n    <input\n      [placeholder]=\"placeholder()\"\n      #inputElm\n      #matAutocompleteTrigger=\"matAutocompleteTrigger\"\n      [formControl]=\"inputCtrl()\"\n      [matAutocomplete]=\"auto\"\n      [matChipInputFor]=\"chipList\"\n      [matChipInputSeparatorKeyCodes]=\"SEPARATOR_KEYS_CODES\"\n      [matChipInputAddOnBlur]=\"allowChipInputAddOnBlur()\"\n      (matChipInputTokenEnd)=\"add($event)\"\n    />\n  </mat-chip-grid>\n  <mat-autocomplete #auto=\"matAutocomplete\" (optionSelected)=\"onSelectOption($event)\">\n    @for (item of filteredValues(); track item) {\n    <mat-option [value]=\"item\">\n      <span>{{ nameGetter(item) }}</span>\n    </mat-option>\n    }\n  </mat-autocomplete>\n</mat-form-field>\n", styles: [".pgh-chips-text{margin-inline-end:.375rem}\n"] }]
        }], ctorParameters: () => [], propDecorators: { inputElm: [{
                type: ViewChild,
                args: ['inputElm']
            }], matAutocompleteTrigger: [{
                type: ViewChild,
                args: ['matAutocompleteTrigger']
            }], valueGetter: [{
                type: Input
            }], nameGetter: [{
                type: Input
            }] } });

class PghAutoCompleteModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: PghAutoCompleteModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.13", ngImport: i0, type: PghAutoCompleteModule, declarations: [PghAutoCompleteComponent], imports: [CommonModule,
            MatAutocompleteModule,
            MatChipsModule,
            MatIconModule,
            MatFormFieldModule,
            ReactiveFormsModule,
            FormsModule], exports: [PghAutoCompleteComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: PghAutoCompleteModule, imports: [CommonModule,
            MatAutocompleteModule,
            MatChipsModule,
            MatIconModule,
            MatFormFieldModule,
            ReactiveFormsModule,
            FormsModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: PghAutoCompleteModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        MatAutocompleteModule,
                        MatChipsModule,
                        MatIconModule,
                        MatFormFieldModule,
                        ReactiveFormsModule,
                        FormsModule,
                    ],
                    exports: [PghAutoCompleteComponent],
                    declarations: [PghAutoCompleteComponent],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { PghAutoCompleteComponent, PghAutoCompleteModule };
//# sourceMappingURL=tapsellorg-angular-material-library-src-lib-auto-complete.mjs.map
