import * as i0 from '@angular/core';
import { input, model, computed, ChangeDetectionStrategy, ViewEncapsulation, Component, signal, NgModule } from '@angular/core';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i2 from '@angular/material/form-field';
import { MatFormFieldModule } from '@angular/material/form-field';
import * as i3 from '@angular/material/select';
import { MatSelectModule } from '@angular/material/select';
import * as i4 from '@angular/forms';
import { NG_VALUE_ACCESSOR, UntypedFormControl, FormsModule, ReactiveFormsModule } from '@angular/forms';
import * as i1$1 from '@angular/material/dialog';
import { MatDialogModule } from '@angular/material/dialog';
import * as i3$1 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import { PghAnimations } from '@tapsellorg/angular-material-library/src/lib/animations';
import * as i3$2 from '@angular/material/chips';
import { MatChipsModule } from '@angular/material/chips';
import * as i4$1 from '@angular/cdk/overlay';
import { OverlayModule } from '@angular/cdk/overlay';
import * as i5 from '@tapsellorg/angular-material-library/src/lib/overlay';
import { PghOverlayModule } from '@tapsellorg/angular-material-library/src/lib/overlay';
import * as i6 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';

const PGH_DEFAULT_START_HOURS = Array.from({ length: 24 }, (_, i) => i);
const PGH_DEFAULT_END_HOURS = Array.from({ length: 24 }, (_, i) => i + 1);

class PghHourRangePickerComponent {
    constructor() {
        this.color = input('primary');
        this.startHourOptions = input(PGH_DEFAULT_START_HOURS);
        this.endHourOptions = input(PGH_DEFAULT_END_HOURS);
        this.startTime = model(undefined);
        this.endTime = model(undefined);
        this.filteredEndHourOptions = computed(() => this.endHourOptions()?.filter(t => t > (this.startTime() ?? 0)));
    }
    startTimeChange() {
        const start = this.startTime() ?? 0;
        const end = this.endTime();
        if (start != null && end != null && end <= start) {
            this.endTime.set(undefined);
        }
        this.updateHourRange();
    }
    endTimeChange() {
        this.updateHourRange();
    }
    writeValue(value) {
        if (!value?.startHour && !value?.endHour)
            return;
        const { startHour, endHour } = value;
        this.startTime.set(startHour);
        this.endTime.set(endHour);
    }
    registerOnChange(fn) {
        this.controlOnChange = fn;
    }
    registerOnTouched(_fn) { }
    updateHourRange() {
        const start = this.startTime();
        const end = this.endTime();
        if (start == null || end == null)
            return;
        this.controlOnChange?.({ startHour: this.startTime(), endHour: this.endTime() });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: PghHourRangePickerComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.13", type: PghHourRangePickerComponent, isStandalone: false, selector: "pgh-hour-range-picker", inputs: { color: { classPropertyName: "color", publicName: "color", isSignal: true, isRequired: false, transformFunction: null }, startHourOptions: { classPropertyName: "startHourOptions", publicName: "startHourOptions", isSignal: true, isRequired: false, transformFunction: null }, endHourOptions: { classPropertyName: "endHourOptions", publicName: "endHourOptions", isSignal: true, isRequired: false, transformFunction: null }, startTime: { classPropertyName: "startTime", publicName: "startTime", isSignal: true, isRequired: false, transformFunction: null }, endTime: { classPropertyName: "endTime", publicName: "endTime", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { startTime: "startTimeChange", endTime: "endTimeChange" }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: PghHourRangePickerComponent,
                multi: true,
            },
        ], ngImport: i0, template: "<mat-form-field class=\"pgh-hour-range-picker-start\" [color]=\"color()\">\n  <mat-label>\u0633\u0627\u0639\u062A \u0634\u0631\u0648\u0639</mat-label>\n  <mat-select [(ngModel)]=\"startTime\" (selectionChange)=\"startTimeChange()\">\n    <mat-select-trigger>\n      <ng-container *ngTemplateOutlet=\"timeTemplate; context: { hour: startTime() }\"></ng-container>\n    </mat-select-trigger>\n    @for (t of startHourOptions(); track t) {\n    <mat-option [value]=\"t\">\n      <ng-container *ngTemplateOutlet=\"timeTemplate; context: { hour: t }\"></ng-container>\n    </mat-option>\n    }\n  </mat-select>\n</mat-form-field>\n\n<mat-form-field [color]=\"color()\">\n  <mat-label>\u0633\u0627\u0639\u062A \u067E\u0627\u06CC\u0627\u0646</mat-label>\n  <mat-select [(ngModel)]=\"endTime\" (selectionChange)=\"endTimeChange()\">\n    <mat-select-trigger>\n      <ng-container *ngTemplateOutlet=\"timeTemplate; context: { hour: endTime() }\"></ng-container>\n    </mat-select-trigger>\n    @for (t of filteredEndHourOptions(); track t) {\n    <mat-option [value]=\"t\">\n      <ng-container *ngTemplateOutlet=\"timeTemplate; context: { hour: t }\"></ng-container>\n    </mat-option>\n    }\n  </mat-select>\n</mat-form-field>\n\n<ng-template #timeTemplate let-hour=\"hour\">\n  <span class=\"d-inline-block ltr\">{{ hour >= 10 ? hour : '0' + hour }} : 00</span>\n</ng-template>\n", styles: [".pgh-hour-range-picker-start{margin-inline-end:.75rem}\n"], dependencies: [{ kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: i2.MatFormField, selector: "mat-form-field", inputs: ["hideRequiredMarker", "color", "floatLabel", "appearance", "subscriptSizing", "hintLabel"], exportAs: ["matFormField"] }, { kind: "directive", type: i2.MatLabel, selector: "mat-label" }, { kind: "component", type: i3.MatSelect, selector: "mat-select", inputs: ["aria-describedby", "panelClass", "disabled", "disableRipple", "tabIndex", "hideSingleSelectionIndicator", "placeholder", "required", "multiple", "disableOptionCentering", "compareWith", "value", "aria-label", "aria-labelledby", "errorStateMatcher", "typeaheadDebounceInterval", "sortComparator", "id", "panelWidth", "canSelectNullableOptions"], outputs: ["openedChange", "opened", "closed", "selectionChange", "valueChange"], exportAs: ["matSelect"] }, { kind: "directive", type: i3.MatSelectTrigger, selector: "mat-select-trigger" }, { kind: "component", type: i3.MatOption, selector: "mat-option", inputs: ["value", "id", "disabled"], outputs: ["onSelectionChange"], exportAs: ["matOption"] }, { kind: "directive", type: i4.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i4.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: PghHourRangePickerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'pgh-hour-range-picker', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: PghHourRangePickerComponent,
                            multi: true,
                        },
                    ], standalone: false, template: "<mat-form-field class=\"pgh-hour-range-picker-start\" [color]=\"color()\">\n  <mat-label>\u0633\u0627\u0639\u062A \u0634\u0631\u0648\u0639</mat-label>\n  <mat-select [(ngModel)]=\"startTime\" (selectionChange)=\"startTimeChange()\">\n    <mat-select-trigger>\n      <ng-container *ngTemplateOutlet=\"timeTemplate; context: { hour: startTime() }\"></ng-container>\n    </mat-select-trigger>\n    @for (t of startHourOptions(); track t) {\n    <mat-option [value]=\"t\">\n      <ng-container *ngTemplateOutlet=\"timeTemplate; context: { hour: t }\"></ng-container>\n    </mat-option>\n    }\n  </mat-select>\n</mat-form-field>\n\n<mat-form-field [color]=\"color()\">\n  <mat-label>\u0633\u0627\u0639\u062A \u067E\u0627\u06CC\u0627\u0646</mat-label>\n  <mat-select [(ngModel)]=\"endTime\" (selectionChange)=\"endTimeChange()\">\n    <mat-select-trigger>\n      <ng-container *ngTemplateOutlet=\"timeTemplate; context: { hour: endTime() }\"></ng-container>\n    </mat-select-trigger>\n    @for (t of filteredEndHourOptions(); track t) {\n    <mat-option [value]=\"t\">\n      <ng-container *ngTemplateOutlet=\"timeTemplate; context: { hour: t }\"></ng-container>\n    </mat-option>\n    }\n  </mat-select>\n</mat-form-field>\n\n<ng-template #timeTemplate let-hour=\"hour\">\n  <span class=\"d-inline-block ltr\">{{ hour >= 10 ? hour : '0' + hour }} : 00</span>\n</ng-template>\n", styles: [".pgh-hour-range-picker-start{margin-inline-end:.75rem}\n"] }]
        }], ctorParameters: () => [] });

class PghHourRangePickerDialogComponent {
    constructor(matDialogRef) {
        this.matDialogRef = matDialogRef;
        this.hourRange = new UntypedFormControl();
    }
    ngOnInit() { }
    submit() {
        this.matDialogRef.close(this.hourRange.value);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: PghHourRangePickerDialogComponent, deps: [{ token: i1$1.MatDialogRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.13", type: PghHourRangePickerDialogComponent, isStandalone: false, selector: "pgh-hour-range-picker-dialog", ngImport: i0, template: "<h1 matDialogTitle class=\"d-flex align-items-center\">\n  <span>\u0627\u0646\u062A\u062E\u0627\u0628 \u0628\u0627\u0632\u0647\u200C\u06CC \u0632\u0645\u0627\u0646\u06CC</span>\n</h1>\n\n<mat-dialog-content>\n  <pgh-hour-range-picker [formControl]=\"hourRange\"></pgh-hour-range-picker>\n</mat-dialog-content>\n\n<mat-dialog-actions>\n  <button mat-raised-button color=\"primary\" (click)=\"submit()\" type=\"button\">\u0627\u0646\u062A\u062E\u0627\u0628 \u0633\u0627\u0639\u062A</button>\n</mat-dialog-actions>\n", styles: [""], dependencies: [{ kind: "directive", type: i4.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$1.MatDialogTitle, selector: "[mat-dialog-title], [matDialogTitle]", inputs: ["id"], exportAs: ["matDialogTitle"] }, { kind: "directive", type: i1$1.MatDialogActions, selector: "[mat-dialog-actions], mat-dialog-actions, [matDialogActions]", inputs: ["align"] }, { kind: "directive", type: i1$1.MatDialogContent, selector: "[mat-dialog-content], mat-dialog-content, [matDialogContent]" }, { kind: "component", type: i3$1.MatButton, selector: "    button[mat-button], button[mat-raised-button], button[mat-flat-button],    button[mat-stroked-button]  ", exportAs: ["matButton"] }, { kind: "directive", type: i4.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "component", type: PghHourRangePickerComponent, selector: "pgh-hour-range-picker", inputs: ["color", "startHourOptions", "endHourOptions", "startTime", "endTime"], outputs: ["startTimeChange", "endTimeChange"] }], encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: PghHourRangePickerDialogComponent, decorators: [{
            type: Component,
            args: [{ selector: 'pgh-hour-range-picker-dialog', encapsulation: ViewEncapsulation.None, standalone: false, template: "<h1 matDialogTitle class=\"d-flex align-items-center\">\n  <span>\u0627\u0646\u062A\u062E\u0627\u0628 \u0628\u0627\u0632\u0647\u200C\u06CC \u0632\u0645\u0627\u0646\u06CC</span>\n</h1>\n\n<mat-dialog-content>\n  <pgh-hour-range-picker [formControl]=\"hourRange\"></pgh-hour-range-picker>\n</mat-dialog-content>\n\n<mat-dialog-actions>\n  <button mat-raised-button color=\"primary\" (click)=\"submit()\" type=\"button\">\u0627\u0646\u062A\u062E\u0627\u0628 \u0633\u0627\u0639\u062A</button>\n</mat-dialog-actions>\n" }]
        }], ctorParameters: () => [{ type: i1$1.MatDialogRef }] });

class PghHoursRangeChipsComponent {
    constructor() {
        this.color = input('primary');
        this.customHourConflictError = input('این محدوده‌ی زمانی قبلا انتخاب شده'); // TODO: Maybe use snackbar instead
        this.removable = input(false);
        this.selectedHours = signal([]);
        this.startHourOptions = input(PGH_DEFAULT_START_HOURS);
        this.endHourOptions = input(PGH_DEFAULT_END_HOURS);
        this.newHourRange = new UntypedFormControl();
        this.isShowingError = signal(false);
    }
    removeHourRange(hourRange) {
        this.setActiveHours(this.selectedHours().filter(h => h !== hourRange));
    }
    setActiveHours(data) {
        this.selectedHours.set(data);
        this.onChange?.(data);
    }
    writeValue(value) {
        if (!Array.isArray(value) || value.some(o => !this.isHourRange(o)))
            return;
        this.selectedHours.set(value);
    }
    isHourRange(obj) {
        return obj.startHour != null && obj.endHour != null;
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    hasConflictWithOtherRanges({ startHour, endHour }) {
        const betweenRange = (x, { startHour: min, endHour: max }) => x > min && x < max;
        return this.selectedHours().some(hour => betweenRange(startHour, hour) ||
            betweenRange(endHour, hour) ||
            startHour === hour.startHour ||
            endHour === hour.endHour);
    }
    submitAddHourRange() {
        this.onTouched?.();
        const startHour = this.newHourRange.value?.startHour;
        const endHour = this.newHourRange.value?.endHour;
        if (startHour == null || endHour == null || endHour <= startHour)
            return;
        if (this.hasConflictWithOtherRanges(this.newHourRange.value)) {
            this.showError();
            return;
        }
        this.setActiveHours([...this.selectedHours(), this.newHourRange.value]);
    }
    showError() {
        this.isShowingError.set(true);
        setTimeout(() => {
            this.isShowingError.set(false);
        }, 3000);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: PghHoursRangeChipsComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.13", type: PghHoursRangeChipsComponent, isStandalone: false, selector: "pgh-hours-range-chips", inputs: { color: { classPropertyName: "color", publicName: "color", isSignal: true, isRequired: false, transformFunction: null }, customHourConflictError: { classPropertyName: "customHourConflictError", publicName: "customHourConflictError", isSignal: true, isRequired: false, transformFunction: null }, removable: { classPropertyName: "removable", publicName: "removable", isSignal: true, isRequired: false, transformFunction: null }, startHourOptions: { classPropertyName: "startHourOptions", publicName: "startHourOptions", isSignal: true, isRequired: false, transformFunction: null }, endHourOptions: { classPropertyName: "endHourOptions", publicName: "endHourOptions", isSignal: true, isRequired: false, transformFunction: null } }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: PghHoursRangeChipsComponent,
                multi: true,
            },
        ], ngImport: i0, template: "<div class=\"pgh-add-hour-range-chips-container\">\n  <mat-chip-listbox class=\"d-flex align-items-center\">\n    @for (chip of selectedHours(); track chip) {\n    <mat-chip-option [removable]=\"removable()\" (removed)=\"removeHourRange(chip)\">\n      <span class=\"me-1\">{{ chip.startHour }}</span>\n      <span class=\"me-1\">\u062A\u0627</span>\n      <span>{{ chip.endHour }}</span>\n      @if (removable()) {\n      <button matChipRemove>\n        <mat-icon svgIcon=\"close\"></mat-icon>\n      </button>\n      }\n    </mat-chip-option>\n    }\n  </mat-chip-listbox>\n\n  <button\n    mat-button\n    [color]=\"color()\"\n    class=\"pgh-add-hour-range-btn\"\n    cdkOverlayOrigin\n    #chipOverlayOrigin=\"cdkOverlayOrigin\"\n    (click)=\"overlay.open()\"\n  >\n    \u0627\u0641\u0632\u0648\u062F\u0646 \u0633\u0627\u0639\u062A\n  </button>\n</div>\n\n<pgh-overlay [origin]=\"chipOverlayOrigin\" #overlay>\n  <pgh-hour-range-picker\n    [formControl]=\"newHourRange\"\n    [color]=\"color()\"\n    [startHourOptions]=\"startHourOptions()\"\n    [endHourOptions]=\"endHourOptions()\"\n  ></pgh-hour-range-picker>\n\n  <div class=\"d-flex\">\n    @if (isShowingError()) {\n    <div @fadeInOut class=\"text-danger\">{{ customHourConflictError() }}</div>\n    }\n    <button\n      mat-flat-button\n      color=\"primary\"\n      (click)=\"submitAddHourRange()\"\n      type=\"button\"\n      class=\"ms-auto\"\n    >\n      \u0627\u0646\u062A\u062E\u0627\u0628 \u0633\u0627\u0639\u062A\n    </button>\n  </div>\n</pgh-overlay>\n", styles: [".pgh-add-hour-range-chips-container{display:flex}.pgh-add-hour-range-btn{margin-inline-start:.5rem}\n"], dependencies: [{ kind: "directive", type: i4.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "component", type: i3$1.MatButton, selector: "    button[mat-button], button[mat-raised-button], button[mat-flat-button],    button[mat-stroked-button]  ", exportAs: ["matButton"] }, { kind: "directive", type: i4.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "component", type: i3$2.MatChipListbox, selector: "mat-chip-listbox", inputs: ["multiple", "aria-orientation", "selectable", "compareWith", "required", "hideSingleSelectionIndicator", "value"], outputs: ["change"] }, { kind: "component", type: i3$2.MatChipOption, selector: "mat-basic-chip-option, [mat-basic-chip-option], mat-chip-option, [mat-chip-option]", inputs: ["selectable", "selected"], outputs: ["selectionChange"] }, { kind: "directive", type: i3$2.MatChipRemove, selector: "[matChipRemove]" }, { kind: "directive", type: i4$1.CdkOverlayOrigin, selector: "[cdk-overlay-origin], [overlay-origin], [cdkOverlayOrigin]", exportAs: ["cdkOverlayOrigin"] }, { kind: "component", type: i5.PghOverlayComponent, selector: "pgh-overlay", inputs: ["origin", "panelClasses"], exportAs: ["pghOverlay"] }, { kind: "component", type: i6.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "component", type: PghHourRangePickerComponent, selector: "pgh-hour-range-picker", inputs: ["color", "startHourOptions", "endHourOptions", "startTime", "endTime"], outputs: ["startTimeChange", "endTimeChange"] }], animations: [PghAnimations.fadeInOut], encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: PghHoursRangeChipsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'pgh-hours-range-chips', encapsulation: ViewEncapsulation.None, providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: PghHoursRangeChipsComponent,
                            multi: true,
                        },
                    ], animations: [PghAnimations.fadeInOut], standalone: false, template: "<div class=\"pgh-add-hour-range-chips-container\">\n  <mat-chip-listbox class=\"d-flex align-items-center\">\n    @for (chip of selectedHours(); track chip) {\n    <mat-chip-option [removable]=\"removable()\" (removed)=\"removeHourRange(chip)\">\n      <span class=\"me-1\">{{ chip.startHour }}</span>\n      <span class=\"me-1\">\u062A\u0627</span>\n      <span>{{ chip.endHour }}</span>\n      @if (removable()) {\n      <button matChipRemove>\n        <mat-icon svgIcon=\"close\"></mat-icon>\n      </button>\n      }\n    </mat-chip-option>\n    }\n  </mat-chip-listbox>\n\n  <button\n    mat-button\n    [color]=\"color()\"\n    class=\"pgh-add-hour-range-btn\"\n    cdkOverlayOrigin\n    #chipOverlayOrigin=\"cdkOverlayOrigin\"\n    (click)=\"overlay.open()\"\n  >\n    \u0627\u0641\u0632\u0648\u062F\u0646 \u0633\u0627\u0639\u062A\n  </button>\n</div>\n\n<pgh-overlay [origin]=\"chipOverlayOrigin\" #overlay>\n  <pgh-hour-range-picker\n    [formControl]=\"newHourRange\"\n    [color]=\"color()\"\n    [startHourOptions]=\"startHourOptions()\"\n    [endHourOptions]=\"endHourOptions()\"\n  ></pgh-hour-range-picker>\n\n  <div class=\"d-flex\">\n    @if (isShowingError()) {\n    <div @fadeInOut class=\"text-danger\">{{ customHourConflictError() }}</div>\n    }\n    <button\n      mat-flat-button\n      color=\"primary\"\n      (click)=\"submitAddHourRange()\"\n      type=\"button\"\n      class=\"ms-auto\"\n    >\n      \u0627\u0646\u062A\u062E\u0627\u0628 \u0633\u0627\u0639\u062A\n    </button>\n  </div>\n</pgh-overlay>\n", styles: [".pgh-add-hour-range-chips-container{display:flex}.pgh-add-hour-range-btn{margin-inline-start:.5rem}\n"] }]
        }], ctorParameters: () => [] });

class PghHourRangePickerModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: PghHourRangePickerModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.13", ngImport: i0, type: PghHourRangePickerModule, declarations: [PghHourRangePickerComponent,
            PghHourRangePickerDialogComponent,
            PghHoursRangeChipsComponent], imports: [CommonModule,
            MatFormFieldModule,
            MatSelectModule,
            FormsModule,
            MatDialogModule,
            MatButtonModule,
            ReactiveFormsModule,
            MatChipsModule,
            OverlayModule,
            PghOverlayModule,
            MatIconModule], exports: [PghHourRangePickerComponent,
            PghHourRangePickerDialogComponent,
            PghHoursRangeChipsComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: PghHourRangePickerModule, imports: [CommonModule,
            MatFormFieldModule,
            MatSelectModule,
            FormsModule,
            MatDialogModule,
            MatButtonModule,
            ReactiveFormsModule,
            MatChipsModule,
            OverlayModule,
            PghOverlayModule,
            MatIconModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: PghHourRangePickerModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        PghHourRangePickerComponent,
                        PghHourRangePickerDialogComponent,
                        PghHoursRangeChipsComponent,
                    ],
                    imports: [
                        CommonModule,
                        MatFormFieldModule,
                        MatSelectModule,
                        FormsModule,
                        MatDialogModule,
                        MatButtonModule,
                        ReactiveFormsModule,
                        MatChipsModule,
                        OverlayModule,
                        PghOverlayModule,
                        MatIconModule,
                    ],
                    exports: [
                        PghHourRangePickerComponent,
                        PghHourRangePickerDialogComponent,
                        PghHoursRangeChipsComponent,
                    ],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { PGH_DEFAULT_END_HOURS, PGH_DEFAULT_START_HOURS, PghHourRangePickerComponent, PghHourRangePickerDialogComponent, PghHourRangePickerModule, PghHoursRangeChipsComponent };
//# sourceMappingURL=tapsellorg-angular-material-library-src-lib-hour-range-picker.mjs.map
