export declare class JalaliDate {
    year: number;
    month: number;
    day: number;
    constructor(year: number, month: number, day: number);
    static from(value: JalaliDate | Date | string | number): JalaliDate;
    /**
     * string type is the jalali form of date: 1399/01/30
     */
    static parse(value: string, parseFormat: string | string[]): JalaliDate;
    clone(): JalaliDate;
    isValid(): boolean;
    dayOfWeek(): number;
    format(displayFormat?: string): string;
    addYears: (years: number) => this;
    addMonths: (months: number) => this;
    setJalaliMonth(month: number): this;
    setJalaliDay(day: number): this;
    addDays: (days: number) => this;
}
declare class GregorianJalaliHelperClass {
    /**
     * Returns the equivalent jalali date value for a give input Gregorian date.
     * `gdate` is a JS Date to be converted to jalali.
     * utc to local
     */
    fromGregorian(gdate: Date): JalaliDate;
    gregorianToDay(gy: number, gm: number, gd: number): number;
    dayToJalali(julianDayNumber: number): JalaliDate;
    /**
     * Returns the equivalent JS date value for a give input Jalali date.
     * `jalaliDate` is an Jalali date to be converted to Gregorian.
     */
    toGregorian(jalaliDate: JalaliDate): Date;
    jalaliToDay(jYear: number, jMonth: number, jDay: number): number;
    dayToGregorian(julianDayNumber: number): Date;
    jalCal(jalaliYear: number): {
        leap: number;
        gy: number;
        march: number;
    };
    getDaysPerMonth(month: number, year: number): number;
}
export declare const GregorianJalaliHelper: GregorianJalaliHelperClass;
export declare const LONG_MONTHS: string[];
export declare const ISO_DATE_REGEX: RegExp;
export declare function isDateStringIso(dateString: string): boolean;
export {};
